Module join_ops

Module join_ops 

Auto-extracted from physical_operator.rs

Structs

JoinHashTable
A hash table for hash join operations with parallel build support.
PhysicalAntiJoin
Physical anti-join: Returns left rows that have NO matching join key in the right side. Only left-side columns are emitted.
PhysicalCrossProduct
Physical cross product (Cartesian product) operator.
PhysicalHashJoin
PhysicalIntersect
Physical intersect operator.
PhysicalSemiJoin
Physical semi-join: Returns left rows that have a matching join key in the right side. Only left-side columns are emitted (no right columns in output).