pub struct PhysicalAccumulate;Expand description
Accumulate — materializes all input into a single contiguous chunk in memory.
This is required for operations that need random access to all rows, such as hash join build side, correlated subqueries, etc.