pub struct ResultCollector;Expand description
ResultCollector — collects all input DataChunks into a single result set.
This is the final operator in the query pipeline. It consolidates
all chunks into a single Vec<DataChunk> ready for client return.
If there are multiple input chunks, they are merged into one.