pub struct PhysicalArtIndexRangeScan {
pub table_name: String,
pub table_id: u64,
pub lower_bound: Option<Value>,
pub upper_bound: Option<Value>,
pub lower_inclusive: bool,
pub upper_inclusive: bool,
pub table_catalog: Option<Arc<TableCatalog>>,
}Expand description
Physical operator for ART index range scans.
Uses the ART index on a node table’s PK column to efficiently find rows within a key range, then fetches the full column data for those rows.
Pattern follows PhysicalVectorSimilarityScan.
Fields
table_name: Stringtable_id: u64lower_bound: Option<Value>upper_bound: Option<Value>lower_inclusive: boolupper_inclusive: booltable_catalog: Option<Arc<TableCatalog>>Trait Implementations
Sourceimpl Clone for PhysicalArtIndexRangeScan
impl Clone for PhysicalArtIndexRangeScan
Sourcefn clone(&self) -> PhysicalArtIndexRangeScan
fn clone(&self) -> PhysicalArtIndexRangeScan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PhysicalArtIndexRangeScan
impl Debug for PhysicalArtIndexRangeScan
Sourceimpl PhysicalOperatorExec for PhysicalArtIndexRangeScan
impl PhysicalOperatorExec for PhysicalArtIndexRangeScan
fn operator_type(&self) -> &str
fn execute(&self, _input: Vec<DataChunk>) -> OperatorResult