pub struct ExpressionEvaluator {
pub subquery_fn: Option<SubqueryFn>,
pub sequence_fn: Option<SequenceFn>,
/* private fields */
}Fields
subquery_fn: Option<SubqueryFn>Optional callback to execute subqueries at evaluation time. Takes a parsed Query and returns DataChunks.
sequence_fn: Option<SequenceFn>Optional callback for sequence operations (nextval/currval). Takes (sequence_name, is_nextval) and returns the resulting value.
Implementations
Sourceimpl ExpressionEvaluator
impl ExpressionEvaluator
pub fn new(registry: Arc<Mutex<FunctionRegistry>>) -> Self
Sourcepub fn with_subquery_fn(self, f: SubqueryFn) -> Self
pub fn with_subquery_fn(self, f: SubqueryFn) -> Self
Set the subquery execution callback.
Sourcepub fn with_sequence_fn(self, f: SequenceFn) -> Self
pub fn with_sequence_fn(self, f: SequenceFn) -> Self
Set the sequence operation callback (for nextval/currval).
Sourcepub fn evaluate_to_arrow(
&self,
expr: &Expression,
chunk: &DataChunk,
) -> Result<ArrowVector, ProcessorError>
pub fn evaluate_to_arrow( &self, expr: &Expression, chunk: &DataChunk, ) -> Result<ArrowVector, ProcessorError>
Evaluate an expression for every row in the chunk, returning an ArrowVector directly. Delegates to evaluate_arrow which uses Arrow compute kernels for the hot path (comparisons, arithmetic, boolean ops).
Sourcepub fn evaluate(
&self,
expr: &Expression,
chunk: &DataChunk,
) -> Result<ValueVector, ProcessorError>
pub fn evaluate( &self, expr: &Expression, chunk: &DataChunk, ) -> Result<ValueVector, ProcessorError>
Evaluate an expression for every row in the chunk, returning a ValueVector.
Sourcepub fn evaluate_arrow(
&self,
expr: &Expression,
chunk: &DataChunk,
) -> Result<ArrowVector, ProcessorError>
pub fn evaluate_arrow( &self, expr: &Expression, chunk: &DataChunk, ) -> Result<ArrowVector, ProcessorError>
Evaluate an expression returning an ArrowVector directly. For operations supported by Arrow compute kernels (comparisons, arithmetic, boolean), this is vectorized and avoids Value enum boxing.