pub struct PhysicalCrossProduct;Expand description
Physical cross product (Cartesian product) operator.
Combines every row from the left side with every row from the right side. The left side is the first half of input chunks, the right side is the second half.
Implementations
Sourceimpl PhysicalCrossProduct
impl PhysicalCrossProduct
pub fn execute_binary( &self, left_chunks: &[DataChunk], right_chunks: &[DataChunk], ) -> OperatorResult