Query processor — maps logical operators to physical operators and executes them.
Pipeline execution model:
- Scan operators produce raw DataChunks
- Filter removes non-matching rows
- Projection selects/transforms columns
- Limit/OrderBy/Aggregate are applied last
Re-exports
pub use chunk_helpers::*;pub use join_helpers::*;pub use mapper::*;pub use plan_serializer::*;pub use projection_helper::*;pub use union_helpers::*;
Modules
Structs
- Query
Processor - The query processor executes a physical plan and produces result chunks.
- Standalone
Call Registry
Enums
- Schema
DdlOp - DDL operations that require the schema-level Catalog (from Akar-catalog). These are dispatched via callback because the processor layer doesn’t directly own the schema catalog.